@@ -8,9 +8,8 @@ from rest_framework.response import Response
 from rest_framework_simplejwt.settings import api_settings
 from rest_framework_simplejwt.views import TokenViewBase
 
-from drf_auth_service.authentication.serializers import LoginSerializer, CustomTokenRefreshSerializer, \
-    ReturnRegisterSerializer, ReturnAccessTokenSerializer, ReturnJWTTokensSerializer
-from drf_auth_service.common.backends import BaseBackend
+from drf_auth_service.authentication.serializers import CustomTokenRefreshSerializer, \
+    ReturnRegisterSerializer, ReturnAccessTokenSerializer
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
 from drf_auth_service.common.permissions import ServiceTokenPermission
@@ -45,6 +44,16 @@ class AuthenticationViewSet(GenericEBSViewSet):
         manager.send_reset_password(serializer.validated_data['user'])
         return Response(self.get_serializer(dict(message='Reset password was sent successfully')).data)
 
+    @action(detail=False, methods=['POST'], url_path='restore-verify',
+            serializer_class=settings.SERIALIZERS.RETURN_SUCCESS_SERIALIZER,
+            serializer_create_class=settings.SERIALIZERS.RESET_PASSWORD_VERIFY_SERIALIZER)
+    def reset_password_verify(self, request, *args, **kwargs):
+        serializer = self.get_serializer_create(data=request.data)
+        message = 'Valid Token' if serializer.is_valid() else 'Invalid Token'
+        return Response(self.get_serializer(
+            dict(success=serializer.is_valid(), message=message)
+        ).data)
+
     @action(detail=False, methods=['POST'], url_path='restore-confirm',
             serializer_class=settings.SERIALIZERS.RETURN_SUCCESS_SERIALIZER,
             serializer_create_class=settings.SERIALIZERS.RESET_PASSWORD_CONFIRMATION_SERIALIZER)
@@ -56,7 +65,7 @@ class AuthenticationViewSet(GenericEBSViewSet):
         reset_password_token = serializer.validated_data['token']
         reset_password_token.user.set_password(password)
         reset_password_token.user.save()
-
+        reset_password_token.delete()
         return Response(self.get_serializer(dict(message='Password was reset successfully')).data)
 
     @swagger_auto_schema(method='GET', request_body=no_body, responses={})
@@ -76,10 +85,10 @@ class AuthenticationViewSet(GenericEBSViewSet):
 
 
 class LoginViewSet(TokenViewBase):
-    serializer_class = LoginSerializer
+    serializer_class = settings.SERIALIZERS.LOGIN_SERIALIZER
     permission_classes = (ServiceTokenPermission,)
 
-    @swagger_auto_schema(request_body=LoginSerializer, responses={200: jwt_response})
+    @swagger_auto_schema(request_body=settings.SERIALIZERS.LOGIN_SERIALIZER, responses={200: jwt_response})
     def post(self, request, *args, **kwargs):
         api_settings.SIGNING_KEY = request.service.secret_token
         response = super(LoginViewSet, self).post(request, *args, **kwargs)
