@@ -1,4 +1,5 @@
 from abc import abstractmethod
+from urllib.parse import urlparse
 
 import sib_api_v3_sdk
 from django.core.exceptions import ImproperlyConfigured
@@ -17,9 +18,11 @@ class BaseEmailBackend:
     configs = {}
     template_reset = None
     template_confirm = None
+    request = None
 
-    def __init__(self, configs: dict):
+    def __init__(self, configs: dict, request):
         self.configs = configs
+        self.request = request
         self.config_backend()
 
     @abstractmethod
@@ -104,7 +107,12 @@ class HtmlTemplateBackend(BaseEmailBackend):
 
     def send_reset_password(self, user):
         token = ActivationCode.create_token(user, ActivationCode.CodeTypes.RESET_PASSWORD)
-        send_reset_pass_url = f"{settings.SEND_RESET_PASSWORD_URL}{token.key}"
+        try:
+            domain = urlparse(self.request.headers['Origin']).netloc
+        except: # noqa
+            domain = 'example.com'
+
+        send_reset_pass_url = f"{domain}{settings.SEND_RESET_PASSWORD_PREFIX}{token.key}"
         self.send(self.get_template(self.template_reset), email=user.username, default_template='reset_password.html',
                   send_reset_pass_url=send_reset_pass_url, subject=self.configs['HTML_RESET_PASSWORD_SUBJECT'])
 
