@@ -13,9 +13,11 @@ class BasePhoneBackend:
     configs = {}
     template_reset = 'SMS_RESET_PASSWORD_MESSAGE'
     template_confirm = 'SMS_CONFIRMATION_MESSAGE'
+    request = None
 
-    def __init__(self, configs: dict):
+    def __init__(self, configs: dict, request):
         self.configs = configs
+        self.request = request
         self.config_backend()
 
     @abstractmethod
