@@ -58,7 +58,7 @@ default_sso_settings = {
     "MAILCHIMP_SECRET_KEY": None,
     "SEND_CONFIRMATION": True,
     "RESET_PASSWORD_EXPIRE": 24,
-    "SEND_RESET_PASSWORD_URL": 'https://example.com/reset-password/',
+    "SEND_RESET_PASSWORD_PREFIX": '',
     "SEND_CONFIRMATION_URL": 'https://example.com/confirm-email/',
     "TWILIO_ACCOUNT_SID": "AC6b3fc1744aa63d35235a4fb01241e71a",
     "TWILIO_AUTH_TOKEN": "a3e0f68829427c69dbb94cb4e95ff638",
@@ -89,13 +89,16 @@ default_sso_settings = {
         "REGISTER_RETURN_SERIALIZER": "drf_auth_service.authentication.serializers.ReturnRegisterSerializer",
         "SEND_RESET_PASSWORD_SERIALIZER": "drf_auth_service.authentication.serializers.SendResetPasswordSerializer",
         "RESET_PASSWORD_CONFIRMATION_SERIALIZER": "drf_auth_service.authentication.serializers.ResetPasswordConfirmSerializer",
+        "RESET_PASSWORD_VERIFY_SERIALIZER": "drf_auth_service.authentication.serializers.ResetPasswordVerifySerializer",
         "RETURN_SUCCESS_SERIALIZER": "drf_auth_service.authentication.serializers.ReturnSuccessSerializer",
         "SET_PASSWORD_SERIALIZER": "drf_auth_service.users.serializers.UserSetPasswordSerializer",
+        "LOGIN_SERIALIZER": "drf_auth_service.authentication.serializers.LoginSerializer",
     }),
     "VIEWS": ObjDict({
         "USER_VIEWS": "drf_auth_service.users.views.UserViewSet",
         "SERVICE_VIEWS": "drf_auth_service.services.views.ServiceViewSet",
         "AUTHENTICATION_VIEWS": "drf_auth_service.authentication.views.AuthenticationViewSet",
+        "AUTHENTICATION_LOGIN_VIEWS": "drf_auth_service.authentication.views.LoginViewSet",
     }),
     "PERMISSIONS": ObjDict({
         "USER_PERMISSIONS": "drf_auth_service.users.permissions.USER_PERMISSIONS",
