@@ -11,7 +11,7 @@ router.register(r'users', settings.VIEWS.USER_VIEWS, basename='user')
 router.register(r'authentication', settings.VIEWS.AUTHENTICATION_VIEWS, basename='authentication')
 
 urlpatterns = router.urls + [
-    path('authentication/login', LoginViewSet.as_view(), name='authentication-login'),
+    path('authentication/login', settings.VIEWS.AUTHENTICATION_LOGIN_VIEWS.as_view(), name='authentication-login'),
     path('authentication/oauth', social_login, name='social_login'),
     path('authentication/refresh', EBSTokenRefreshView.as_view(), name='authentication-refresh')
 ]
